"""
Age tab
"""
from datetime import datetime, timedelta

from .tab import Tab
from ...tree.model import TreeStore
from ...tree.model import TreeStoreColumnMetadata as ColumnMetadata
from ...db.model import Project, Bug, BugTask


class AgeTab(Tab):
    """
    `Tab` that displays all bugs age
    """
    id = 'age'
    ICON_BASENAME = 'bug.png'

    def __init__(self, application):
        icon_image = self._get_icon_image(self.ICON_BASENAME)
        super(AgeTab, self).__init__('age.ui',
                                     icon_image, application)
        self.title = 'Age'

        store = TreeStore('bugtasks',
                          (ColumnMetadata('bug_id', int),
                           ColumnMetadata('project', str),
                           ColumnMetadata('age', int),
                          ))
        self.bugtasks_store = store
        self.bugtasks_treeview.set_model(store)
        self.refresh()

    def refresh(self):
        """
        Refresh tab content
        """
        session = self.application.db.session
        store = self.bugtasks_store
        store.clear()

        bugtasks = (session.query(BugTask)
                    .join(Bug).order_by(Bug.id)
                    .join(Project).order_by(Project.name))
        bugtask_ages = []
        for bugtask in bugtasks:
            project = bugtask.project.name
            date_created = bugtask.date_created
            date_closed = bugtask.date_closed
            date_reopened = bugtask.date_reopened
            if date_reopened:
                age = datetime.now() - date_created
            elif date_closed:
                age = date_closed - date_created
            else:
                age = datetime.now() - date_created
            bugtask_ages.append(age)
            store.append(None, (bugtask.bug_id, project, age.days))
        bugtask_age_average = (sum(bugtask_ages, timedelta())
                               / len(bugtask_ages))
        self.age_average_label.set_text('{0} days average age'
                                        .format(bugtask_age_average.days))
