"""
Regression tab
"""
from .tab import Tab
from ...tree.model import TreeStore
from ...tree.model import TreeStoreColumnMetadata as ColumnMetadata
from ...db.model import Project, Bug, BugTask


class RegressionTab(Tab):
    """
    `Tab` that displays all bugs age
    """
    id = 'regression'
    ICON_BASENAME = 'bug.png'

    def __init__(self, application):
        icon_image = self._get_icon_image(self.ICON_BASENAME)
        super(RegressionTab, self).__init__('regression.ui',
                                            icon_image, application)
        self.title = 'Regressions'

        store = TreeStore('bugtasks',
                          (ColumnMetadata('bug_id', int),
                           ColumnMetadata('project', str),
                           ColumnMetadata('closed', str),
                           ColumnMetadata('reopened', str),
                          ))
        self.bugtasks_store = store
        self.bugtasks_treeview.set_model(store)
        self.refresh()

    def refresh(self):
        """
        Refresh tab content
        """
        session = self.application.db.session
        store = self.bugtasks_store
        store.clear()

        bugtasks = (session.query(BugTask)
                    .filter(BugTask.date_reopened != None)
                    .join(Bug).order_by(Bug.id)
                    .join(Project).order_by(Project.name))
        for bugtask in bugtasks:
            bug_id = bugtask.bug_id
            project = bugtask.project.name
            closed = bugtask.date_closed.strftime('%c')
            reopened = bugtask.date_reopened.strftime('%c')
            row_tuple = (bug_id, project, closed, reopened)
            store.append(None, row_tuple)
        self.regressions_count_label.set_text('{0} regressions found'
                                              .format(len(store)))
