"""
Unverified tab
"""
from .tab import Tab
from ...tree.model import TreeStore
from ...tree.model import TreeStoreColumnMetadata as ColumnMetadata
from ...db.model import Bug, Status


class UnverifiedTab(Tab):
    """
    `Tab` that displays a list of fixed, but unverified bugs
    """
    id = 'unverified'
    ICON_BASENAME = 'bug.png'

    def __init__(self, application):
        icon_image = self._get_icon_image(self.ICON_BASENAME)
        super(UnverifiedTab, self).__init__('unverified.ui',
                                            icon_image, application)
        self.title = 'Unverified'

        store = TreeStore('bugtasks',
                          (ColumnMetadata('bug_id', int),
                           ColumnMetadata('status', str),
                           ColumnMetadata('tags', str),
                          ))
        self.bugtasks_store = store
        self.bugtasks_treeview.set_model(store)
        self.refresh()

    def refresh(self):
        """
        Refresh tab content
        """
        session = self.application.db.session
        fix_committed = (session.query(Status)
                         .filter_by(name='Fix Committed').one())
        fix_released = (session.query(Status)
                        .filter_by(name='Fix Released').one())
        fixed = (fix_committed, fix_released)
        unverified_bugs = []

        store = self.bugtasks_store
        store.clear()
        bugs = session.query(Bug).all()
        for bug in bugs:
            bug_fixed = any(bugtask.bugtaskview_set.first().status in fixed
                            for bugtask in bug.bugtask_set.all())
            if bug_fixed:
                bugview = bug.bugview_set.first()
                if bugview:
                    tags = [bugviewtag.tag.name
                            for bugviewtag in bugview.bugviewtag_set.all()]
                    bug_verified = 'cqa-verified' in tags
                    if not bug_verified:
                        unverified_bugs.append(bug)
                else:
                    unverified_bugs.append(bug)

        for bug in unverified_bugs:
            bug_id = bug.id
            bugview = bug.bugview_set.first()
            if bugview:
                tags = sorted([bugviewtag.tag.name
                               for bugviewtag in bugview.bugviewtag_set.all()])
                tags = ', '.join(tags)
            else:
                tags = ''

            bugtasks = bug.bugtask_set.all()
            for bugtask in bugtasks:
                bugtaskview = bugtask.bugtaskview_set.first()
                status = bugtaskview.status
                if status in fixed:
                    status = status.name
                    store.append(None, (bug_id, status, tags))

        self.bugtaskviews_label.set_text('{0} bug tasks found'
                                         .format(len(store)))
