"""
Utility classes and functions
"""
from contextlib import contextmanager
from itertools import count, izip

from gi.repository import Gdk


@contextmanager
def critical_section():
    Gdk.threads_enter()
    yield
    Gdk.threads_leave()


class Enumeration(object):
    """
    Enumerate multiple iterables in different calls
    using the same counter
    """
    def __init__(self):
        """
        Initilize counter
        """
        self.counter = count()

    def __call__(self, iterable):
        """
        Enumerate a new iterable
        """
        # iterable and counter are swapped
        # to avoid consuming from counter
        # when iterable has been exhausted
        for element, index in izip(iterable, self.counter):
            yield index, element
