#!/usr/bin/python
import subprocess
from distutils.core import setup


def get_version():
    """
    Get changelog version based on dpkg-parsechangelog tool
    """
    process = subprocess.Popen('dpkg-parsechangelog',
                               stdout=subprocess.PIPE)
    stdout, stderr = process.communicate()
    lines = stdout.splitlines()
    for line in lines:
        parts = line.split(': ')
        if len(parts) == 2:
            key, value = parts
            if key == 'Version':
                return value
    raise ValueError


setup(
    name='bugtimetracker',
    version=get_version(),
    description='Get bug information from launchpad and display it nicely',
    author='Javier Collado',
    author_email='javier.collado@canonical.com',
    url='https://code.launchpad.net/~javier.collado/bugtimetracker/trunk',
    license='GPL',
    packages=['bugtimetracker',
              'bugtimetracker.db',
              'bugtimetracker.notebook',
              'bugtimetracker.notebook.tab',
              'bugtimetracker.tree'],
    package_data={'bugtimetracker': ['ui/*.ui',
                                     'ui/dialog/*.ui',
                                     'ui/img/*.png',
                                     'ui/tab/*.ui',
                                     ], },
    scripts=['bin/bugtimetracker'],
)
